package de.fhhannover.inform.trust.ifmapcli;

import java.io.FileNotFoundException;
import java.io.InputStream;

import javax.net.ssl.TrustManager;

import de.fhhannover.inform.trust.ifmapcli.common.Common;
import de.fhhannover.inform.trust.ifmapcli.common.Config;
import de.fhhannover.inform.trust.ifmapj.IfmapJ;
import de.fhhannover.inform.trust.ifmapj.IfmapJHelper;
import de.fhhannover.inform.trust.ifmapj.channel.SSRC;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.exception.InitializationException;

/**
 * A simple tool that purges a publisher </br>.
 * 
 * @author ib
 *
 */
public class Purge {
	final static String CMD = "purge";
	final static int MIN_ARGS = 1;			// me|<some-publisher-id>
	final static int EXPECTED_ARGS = 6;		// me|<some-publisher-id>
											// url, user, pass,
											// keystorePath, keystorePass
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		String pId;
		Config cfg;
		SSRC ssrc;
		TrustManager[] tms;
		InputStream is;
		
		// check number of mandatory command line arguments
		if(args.length < MIN_ARGS){
			Purge.usage();
			return;
		}
		
		// parse mandatory command line arguments
		pId = args[0];
		
		// check and load optional parameters
		cfg = Common.checkAndLoadParams(args, EXPECTED_ARGS);
		System.out.println(CMD + " uses config " + cfg);
		
		// purge
		try {
			is = Common.prepareTruststoreIs(cfg.getTruststorePath());
			tms = IfmapJHelper.getTrustManagers(is, cfg.getTruststorePass());
			ssrc = IfmapJ.createSSRC(cfg.getUrl(), cfg.getUser(), cfg.getPass(), tms);
			ssrc.newSession();
			if(pId.equals("me")){
				ssrc.purgePublisher();				
			} else {
				ssrc.purgePublisher(pId);
			}
			ssrc.endSession();
		} catch (InitializationException e) {
			System.out.println(e.getDescription() + " " + e.getMessage());
		} catch (IfmapErrorResult e) {
			System.out.println(e.getErrorString());
		} catch (IfmapException e) {
			System.out.println(e.getDescription() + " " + e.getMessage());
		} catch (FileNotFoundException e) {
			System.out.println(e.getMessage());
		}
	}
	
	private static void usage() {
		System.out.println("usage:\n" +
				"\t" + Purge.CMD + " me|<some-publisher-id>");
		System.out.println(Common.USAGE);
	}
}
